pub struct ScoringMemberDiff {
pub to_add: Vec<Vec<u8>>,
pub to_remove: Vec<Vec<u8>>,
}Expand description
Members to add to and remove from a scoring table to bring it into sync with the current MLS membership.
Fields
to_add: Vec<Vec<u8>>to_remove: Vec<Vec<u8>>Trait Implementations
Sourceimpl Clone for ScoringMemberDiff
impl Clone for ScoringMemberDiff
Sourcefn clone(&self) -> ScoringMemberDiff
fn clone(&self) -> ScoringMemberDiff
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScoringMemberDiff
impl Debug for ScoringMemberDiff
Sourceimpl Default for ScoringMemberDiff
impl Default for ScoringMemberDiff
Sourcefn default() -> ScoringMemberDiff
fn default() -> ScoringMemberDiff
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ScoringMemberDiff
impl PartialEq for ScoringMemberDiff
Sourcefn eq(&self, other: &ScoringMemberDiff) -> bool
fn eq(&self, other: &ScoringMemberDiff) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ScoringMemberDiff
impl StructuralPartialEq for ScoringMemberDiff